@@ -1,6 +1,6 @@
 // PStreams - POSIX Process I/O for C++
 
-//        Copyright (C) 2001 - 2020 Jonathan Wakely
+//        Copyright (C) 2001 - 2024 Jonathan Wakely
 // Distributed under the Boost Software License, Version 1.0.
 //    (See accompanying file LICENSE_1_0.txt or copy at
 //          http://www.boost.org/LICENSE_1_0.txt)
@@ -44,7 +44,7 @@
 
 
 /// The library version.
-#define PSTREAMS_VERSION 0x0103   // 1.0.3
+#define PSTREAMS_VERSION 0x0104   // 1.0.4
 
 /**
  *  @namespace redi
@@ -81,8 +81,10 @@ namespace redi
     static const pmode newpg   = std::ios_base::trunc;
 
   protected:
-    enum { bufsz = 32 };  ///< Size of pstreambuf buffers.
-    enum { pbsz  = 2 };   ///< Number of putback characters kept.
+    enum {
+      bufsz = 32, ///< Size of pstreambuf buffers.
+      pbsz  = 2   ///< Number of putback characters kept.
+    };
 
 #if __cplusplus >= 201103L
     template<typename T>
@@ -992,29 +994,24 @@ namespace redi
         : basic_rpstream(argv_type(l.begin(), l.end()), mode)
         { }
 
-      // TODO: figure out how to move istream and ostream bases separately,
-      // but so the virtual basic_ios base is only modified once.
-#if 0
       basic_rpstream(basic_rpstream&& rhs)
-      : iostream_type(std::move(rhs))
+      : ostream_type(NULL), istream_type(std::move(rhs))
       , pbase_type(std::move(rhs))
-      { iostream_type::set_rdbuf(std::addressof(pbase_type::buf_)); }
+      { istream_type::set_rdbuf(std::addressof(pbase_type::buf_)); }
 
       basic_rpstream&
       operator=(basic_rpstream&& rhs)
       {
-        iostream_type::operator=(std::move(rhs));
-        pbase_type::operator=(std::move(rhs));
+        swap(rhs);
         return *this;
       }
 
       void
       swap(basic_rpstream& rhs)
       {
-        iostream_type::swap(rhs);
+        istream_type::swap(rhs);
         pbase_type::swap(rhs);
       }
-#endif
 #endif // C++11
 
       /// Destructor
@@ -1618,7 +1615,7 @@ namespace redi
     {
       const bool running = is_open();
 
-      sync(); // this might call wait() and reap the child process
+      basic_pstreambuf::sync(); // might call wait() and reap the child process
 
       // rather than trying to work out whether or not we need to clean up
       // just do it anyway, all cleanup functions are safe to call twice.
@@ -1856,7 +1853,7 @@ namespace redi
     inline bool
     basic_pstreambuf<C,T>::exited()
     {
-      return ppid_ == 0 || wait(true)==1;
+      return ppid_ == 0 || wait(true) == 1;
     }
 
 
