@@ -247,18 +247,25 @@ int main()
 
     {
         // test execve() style construction
-        // should print date on stdout, prefixed by "STDOUT: "
+        // should print date on stdout twice, each prefixed by "STDOUT: "
 
         pstreams::argv_type argv;
         argv.push_back("date");
+        argv.push_back("+%s %c");
         ipstream is1(argv[0], argv);
         ipstream is2(argv);
+        unsigned long t1, t2;
         std::string s1, s2;
-        getline(is1, s1);
-        getline(is2, s2);
-        cout << "STDOUT:  " << s1 << endl;
-        print_result(is1, !s1.empty());
-        print_result(is2, s1 == s2);
+        getline(is1 >> t1, s1);
+        getline(is2 >> t2, s2);
+        cout << "STDOUT:  " << t1 << s1 << endl;
+        cout << "STDOUT:  " << t2 << s2 << endl;
+        print_result(is1, !s1.empty() && s1.length() == s2.length());
+        if (t1 == t2)
+          print_result(is2, s1 == s2);
+        else
+          // This assumes it takes less than 1s to run the two 'date' commands:
+          print_result(is2, (t2 - t1) == 1);
     }
 
     {
@@ -991,6 +998,49 @@ int main()
       str.assign(std::istreambuf_iterator<char>(ps), {});
       check_pass(ps, str == "four\none\nthree\ntwo\n");
     }
+
+    clog << "# Testing rpstream move semantics\n";
+    {
+      std::string line;
+      std::string sh = "while read line; do "
+        "if [ \"$line\" = error ]; then echo ERROR >&2;"
+        "else echo \"$line\";"
+        "fi;"
+        "done";
+      rpstream ps("sh", {"sh", "-c", sh.c_str()}, all3streams);
+      ps << "one" << std::endl;
+      rpstream ps2 = std::move(ps);
+      check_fail(ps << 1);
+      ps2 << "two" << std::endl;
+      check_pass(ps2);
+      getline(ps2.out(), line);
+      check_pass(ps2, line == "one");
+      ps = std::move(ps2);
+      check_fail(ps2.out() >> line);
+      check_fail(ps2.err() >> line);
+      ps << "error" << std::endl;
+      getline(ps.err(), line);
+      print_result(ps, line == "ERROR");
+      getline(ps.out(), line);
+      print_result(ps, line == "two");
+      swap(ps, ps2);
+      check_fail(ps << 1);
+      ps2 << "three\nerror" << std::endl;
+      check_pass(ps2);
+      getline(ps2.err(), line);
+      print_result(ps2, line == "ERROR");
+      getline(ps2.out(), line);
+      print_result(ps2, line == "three");
+      swap(ps, ps2);
+      ps << peof;
+      ps.out() >> line;
+      print_result(ps, ps.out().eof());
+      check_fail(ps);
+      ps.clear();
+      ps.err() >> line;
+      print_result(ps, ps.err().eof());
+      check_fail(ps);
+    }
 #endif
 
     return exit_status;
